@@ -61,7 +61,7 @@ void ffLogoPrintChars(const char* data, bool doColorReplacement)
 
     FF_STRBUF_AUTO_DESTROY result = ffStrbufCreateA(2048);
 
-    if (instance.config.display.brightColor)
+    if (!instance.config.display.pipe && instance.config.display.brightColor)
         ffStrbufAppendS(&result, FASTFETCH_TEXT_MODIFIER_BOLT);
 
     ffStrbufAppendNC(&result, options->paddingTop, '\n');
@@ -70,7 +70,7 @@ void ffLogoPrintChars(const char* data, bool doColorReplacement)
     instance.state.logoHeight = options->paddingTop;
 
     //Use logoColor[0] as the default color
-    if(doColorReplacement)
+    if(doColorReplacement && !instance.config.display.pipe)
         ffStrbufAppendF(&result, "\e[%sm", options->colors[0].chars);
 
     while(*data != '\0')
@@ -143,19 +143,27 @@ void ffLogoPrintChars(const char* data, bool doColorReplacement)
                 continue;
             }
 
-            //Map the number to an array index, so that '1' -> 0, '2' -> 1, etc.
-            int index = ((int) *data) - 49;
-
-            //If the index is valid, print the color. Otherwise continue as normal
-            if(index < 0 || index >= FASTFETCH_LOGO_MAX_COLORS)
+            if(!instance.config.display.pipe)
             {
-                ffStrbufAppendC(&result, '$');
-                ++currentlineLength;
-                //Don't continue here, we want to print the current char as unicode
+                //Map the number to an array index, so that '1' -> 0, '2' -> 1, etc.
+                int index = ((int) *data) - 49;
+
+                //If the index is valid, print the color. Otherwise continue as normal
+                if(index < 0 || index >= FASTFETCH_LOGO_MAX_COLORS)
+                {
+                    ffStrbufAppendC(&result, '$');
+                    ++currentlineLength;
+                    //Don't continue here, we want to print the current char as unicode
+                }
+                else
+                {
+                    ffStrbufAppendF(&result, "\e[%sm", options->colors[index].chars);
+                    ++data;
+                    continue;
+                }
             }
             else
             {
-                ffStrbufAppendF(&result, "\e[%sm", options->colors[index].chars);
                 ++data;
                 continue;
             }
@@ -188,7 +196,8 @@ void ffLogoPrintChars(const char* data, bool doColorReplacement)
         }
     }
 
-    ffStrbufAppendS(&result, FASTFETCH_TEXT_MODIFIER_RESET);
+    if(!instance.config.display.pipe)
+        ffStrbufAppendS(&result, FASTFETCH_TEXT_MODIFIER_RESET);
 
     if(!options->separate)
     {
@@ -460,10 +469,10 @@ static void logoPrintKnownType(void)
 
 void ffLogoPrint(void)
 {
-    //In pipe mode, we don't have a logo or padding.
+    //When generate JSON result, we don't have a logo or padding.
     //We also don't need to set main color, because it won't be printed anyway.
     //So we can return quickly here.
-    if(instance.config.display.pipe || instance.state.resultDoc)
+    if(instance.state.resultDoc)
     {
         instance.state.logoHeight = 0;
         instance.state.logoWidth = 0;
